#!/usr/local/bin/perl 

# Script to run GSEA analysis on multiple datasets (for example, tri21; permutation: phenotype), and mfblood (ranked list, commented out) with 
#  one or more local gmt files (such as p.DFLAT.gmt). For multiple datasets, simply copy the script and replace placeholders for your datasets
# Please see http://www.broadinstitute.org/gsea/doc/GSEAUserGuideFrame.html?Run_GSEA_Page for more information on appropriate settings
#  (such as permutation type, min/max gene set size, ranked list etc)

# Replace X.gmt with name(s) of one or more local .gmt file(s) spearated by spaces (for example, p.DFLAT.gmt p.GOA.gmt)
# Replace /file/path/Y.gct with local file path for .gct file
# Replace /file/path/Z.cls with local file path for .cls file
# Replace /file/path/$gmt with local file path for .gmt file (note that variable $gmt does not need to be changed, as it will be X.gmt in @gmtfiles)
#  (see http://www.broadinstitute.org/cancer/software/gsea/wiki/index.php/Data_formats for more information on GSEA input data formats)
# Replace /file/path/HG_U133_Plus_2.chip with local file path for appropriate human affymetrix microarry .chip file
# Replace /file/path/gsea2-2.07.jar with local file path for GSEA.jar program
#  (download from "Downloads" page at http://www.broadinstitute.org/gsea/index.jsp)
# Replace instances of t21, mfblood, with desired study name(s)

@gmtfiles= qw(X.gmt X.gmt);

foreach $gmt (@gmtfiles) { 
    $outfile = "DFLAT" if ($gmt =~ /DFLAT/ ); #if gmt file name contains DFLAT, place outfile in DFLAT folder
    $outfile = "GOA" if ($gmt =~ /GOA/ ); #if gmt file name contains GOA, place outfile in GOA folder

    $str = "java -cp /file/path/gsea2-2.07.jar
  -Xmx2048m xtools.gsea.Gsea  
  -res /file/path/Y.gct 
  -cls /file/path/Z.cls
  -gmx /file/path/$gmt
  -collapse true
  -mode Max_probe 
  -norm meandiv 
  -nperm 1000
  -permute phenotype
  -rnd_type no_balance 
  -scoring_scheme weighted 
  -rpt_label t21_$outfile
  -metric Signal2Noise 
  -sort real
  -order descending 
  -chip /file/path/HG_U133_Plus_2.chip
  -include_only_symbols true
  -make_sets true
  -median false
  -num 100
  -plot_top_x 40
  -rnd_seed timestamp
  -save_rnd_lists false
  -set_max 150
  -set_min 7
  -zip_report false 
  -out /file/path/$outfile
  -gui false"; 
   
    $str =~ s/\n//g; # remove the newlines, used here for readability
    print "running t21 $outfile\n"; 
    $val = system($str); 

# The following is for a ranked list:

#    $str = "java -cp /file/path/gsea2-2.07.jar
#  -Xmx1024m 
#  xtools.gsea.GseaPreranked 
#  -gmx /file/path/$gmt
#  -collapse true 
#  -mode Max_probe
#  -norm meandiv
#  -nperm 1000
#  -rnk /file/path/mfblood.rnk
#  -scoring_scheme weighted
#  -rpt_label mfblood
#  -chip /file/path/HG_U133A.chip 
#  -include_only_symbols true
#  -make_sets true
#  -plot_top_x 40 
#  -rnd_seed timestamp
#  -set_max 150
#  -set_min 7 
#  -zip_report false 
#  -out /file/path/$outfile
#  -gui false"; 

#    $str =~ s/\n//g; # remove the newlines, used here for readability
#    print "running mfblood $outfile\n"; 
#    $val = system($str); 

}

